==> libvoikko_3.7.orig.tar.gz: libvoikko-3.7/src/fst/Configuration.cpp <==
/* The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Libvoikko: Library of natural language processing tools.
 * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
 * Portions created by the Initial Developer are Copyright (C) 2012
 * the Initial Developer. All Rights Reserved.
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *********************************************************************************/

#include "fst/Configuration.hpp"
#include <sys/types.h>
#include <sys/stat.h>
#include <cstring>

using namespace std;

namespace libvoikko { namespace fst {
	
	Configuration::Configuration(uint16_t flagDiacriticFeatureCount, int bufferSize) :
		bufferSize(bufferSize),
		stackDepth(0),
		inputDepth(0),
		stateIndexStack(new uint32_t[bufferSize]),
		currentTransitionStack(new uint32_t[bufferSize]),
		inputSymbolStack(new uint16_t[bufferSize]),
		outputSymbolStack(new uint16_t[bufferSize]),
		flagValueStack(flagDiacriticFeatureCount ? new uint16_t[flagDiacriticFeatureCount * bufferSize] : 0),
		inputLength(0)
		{
			if (flagDiacriticFeatureCount) {
				// initialize flag values for initial state (these are immutable)
				memset(flagValueStack, 0, flagDiacriticFeatureCount * sizeof(uint16_t));
			}
		}
	
	Configuration::~Configuration() {
		delete[] stateIndexStack;
		delete[] currentTransitionStack;
		delete[] inputSymbolStack;
		delete[] outputSymbolStack;
		delete[] flagValueStack;
	}
} }

==> libvoikko_4.3.3.orig.tar.gz: libvoikko-4.3.3/src/fst/Configuration.cpp <==
/* The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Libvoikko: Library of natural language processing tools.
 * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
 * Portions created by the Initial Developer are Copyright (C) 2012
 * the Initial Developer. All Rights Reserved.
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *********************************************************************************/

#include "fst/Configuration.hpp"
#include <sys/types.h>
#include <sys/stat.h>
#include <cstring>

using namespace std;

namespace libvoikko { namespace fst {
	
	Configuration::Configuration(uint16_t flagDiacriticFeatureCount, int bufferSize) :
		bufferSize(bufferSize),
		stackDepth(0),
		inputDepth(0),
		stateIndexStack(new uint32_t[bufferSize]),
		currentTransitionStack(new uint32_t[bufferSize]),
		inputSymbolStack(new uint16_t[bufferSize]),
		outputSymbolStack(new uint16_t[bufferSize]),
		currentFlagValues(flagDiacriticFeatureCount ? new uint16_t[flagDiacriticFeatureCount] : 0),
		updatedFlagValue(flagDiacriticFeatureCount ? new uint16_t[bufferSize] : 0),
		updatedFlagFeature(flagDiacriticFeatureCount ? new uint16_t[bufferSize] : 0),
		inputLength(0)
		{
			if (flagDiacriticFeatureCount) {
				// initialize flag values for initial state (these are immutable)
				memset(currentFlagValues, 0, flagDiacriticFeatureCount * sizeof(uint16_t));
			}
		}
	
	Configuration::~Configuration() {
		delete[] stateIndexStack;
		delete[] currentTransitionStack;
		delete[] inputSymbolStack;
		delete[] outputSymbolStack;
		delete[] updatedFlagFeature;
		delete[] updatedFlagValue;
		delete[] currentFlagValues;
	}
} }
